-- This Source Code Form is subject to the terms of the bCDDL, v. 1.1.
-- If a copy of the bCDDL was not distributed with this
-- file, You can obtain one at http://beamng.com/bCDDL-1.1.txt

-- OverBoost Protection
-- by wlkmanist, 2023

local M = {}
M.type = "auxiliary"

local engine = nil

local dtTime = 0
local overboostLastTimer = 0

-- Variables
local engineName = "mainEngine"
local boostPsiLimit = 20                                        -- overboost limit threshold
local isEnabled = true                                          -- master switch


local function updateGFX(dt)
  if isEnabled and dtTime and electrics and electrics.values and electrics.values.turboBoost ~= nil then
    if electrics.values.turboBoost >= boostPsiLimit then
      electrics.values.throttle = 0
      overboostLastTimer = dtTime
    end
    if overboostLastTimer ~= 0 and dtTime - overboostLastTimer <= 1 then -- checkengine enabled at least 1 sec after overboost
      electrics.values.checkengine = true
    end
  end
  
  dtTime = dtTime + dt
end

local function reset()
  overboostLastTimer = 0
  dtTime = 0
end

local function init(jbeamData)
  if jbeamData.engineName ~= nil then
    engineName = jbeamData.engineName
  end
  if jbeamData.boostPsiLimit ~= nil then
    boostPsiLimit = jbeamData.boostPsiLimit
  end
  if jbeamData.isEnabled ~= nil then
    isEnabled = jbeamData.isEnabled
  end
  
  engine = powertrain.getDevice(engineName)
  M.updateGFX = engine and updateGFX or nop
  tempRevLimitState = false
end


M.init = init
M.reset = reset
M.updateGFX = nop

return M
